@@ -2,7 +2,7 @@ from HackerGprat import clear
 from pytube import YouTube
 import os
 
-def yt_download(videourl, path="./Output"):
+def yt(videourl, path="./Output"):
 
     clear()
     
@@ -27,14 +27,14 @@ def yt_download(videourl, path="./Output"):
 # urls = []
 
 
-def yt( videoUrl, path="./Output"):
+def yt_download( url ):
     
-    if type( videoUrl ) == str:
-        yt_download(videourl)
+    if type( url ) == str:
+        yt( url )
         
-    elif type( videoUrl ) == list:
-        for link in videoUrl:
-            yt_download( link )
+    elif type( url ) == list:
+        for link in url:
+            yt( link )
     else:
         print("See The Docs & Try Again")
 
